{
  Happy Arts Macrorecorder - TestProjekt
                             MainWindow
  Copyright (c) 1997,1998,1999 by Happy Arts
  Code by Matthias Leonhardt

  Compile with Borland Delphi 2 or newer
}


unit recmain;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  Buttons, Menus, ExtCtrls, ComCtrls, hamacro;

type
  TRecorderMainForm = class(TForm)
    StatusBar: TStatusBar;
    MainMenu: TMainMenu;
    DateiMenu: TMenuItem;
    N1: TMenuItem;
    QuitMenu: TMenuItem;
    MacroFileOpenMenu: TMenuItem;
    MacroMenu: TMenuItem;
    RecordStartMenu: TMenuItem;
    OptionsMenu: TMenuItem;
    ShowTestWindowMenu: TMenuItem;
    RecordStopMenu: TMenuItem;
    N2: TMenuItem;
    PlayMenu: TMenuItem;
    N3: TMenuItem;
    UseOriginSpeedMenu: TMenuItem;
    EnableTaskSwitchMenu: TMenuItem;
    EnableModalMenu: TMenuItem;
    N4: TMenuItem;
    MinimizeMenu: TMenuItem;
    EventListView: TListView;
    N5: TMenuItem;
    ShowEventListMenu: TMenuItem;
    MacroRecorder: TMacroRecorder;
    MacroFileSaveMenu: TMenuItem;
    OpenDialog: TOpenDialog;
    SaveDialog: TSaveDialog;
    Kill3Sekunden1: TMenuItem;
    procedure FormCreate(Sender: TObject);
    procedure ShowTestWindowMenuClick(Sender: TObject);
    procedure QuitMenuClick(Sender: TObject);
    procedure RecordStartMenuClick(Sender: TObject);
    procedure RecordStopMenuClick(Sender: TObject);
    procedure PlayMenuClick(Sender: TObject);
    procedure UseOriginSpeedMenuClick(Sender: TObject);
    procedure EnableTaskSwitchMenuClick(Sender: TObject);
    procedure EnableModalMenuClick(Sender: TObject);
    procedure MinimizeMenuClick(Sender: TObject);
    procedure ShowEventListMenuClick(Sender: TObject);
    procedure MacroRecorderPlayNext;
    procedure MacroRecorderRecordNext;
    procedure MacroRecorderStartPlayBack;
    procedure MacroRecorderStartRecord;
    procedure MacroRecorderStopPlayBack;
    procedure MacroRecorderStopRecord;
    procedure MacroFileOpenMenuClick(Sender: TObject);
    procedure MacroFileSaveMenuClick(Sender: TObject);
    procedure FormKeyDown(Sender: TObject; var Key: Word;
      Shift: TShiftState);
    procedure Kill3Sekunden1Click(Sender: TObject);
  private
    FDoMinimize: Boolean;
  protected
  public
    procedure Status(StatusString: String);
    procedure UpdateMenus;
    property DoMinimize: Boolean read FDoMinimize write FDoMinimize;
  end;

var
  RecorderMainForm: TRecorderMainForm;

implementation

uses
  Macrosup,
  testwin;

{$R *.DFM}

procedure TRecorderMainForm.Status(StatusString: String);
begin
  StatusBar.Panels[0].Text := 'Status: ' + StatusString;
end;

procedure TRecorderMainForm.FormCreate(Sender: TObject);
var
  HotKey: THotKeyRec;
begin
  Caption := Caption + Format('  Version %.2x.%2.2x', [Hi(HAMacroRecorderVersion),
                                                    Lo(HAMacroRecorderVersion)]);
  UseOriginSpeedMenu.Checked := UseOriginalSpeed in MacroRecorder.Options;
  EnableTaskSwitchMenu.Checked := EnableTaskSwitch in MacroRecorder.Options;
  EnableModalMenu.Checked := EnableModalRecording in MacroRecorder.Options;
  FDoMinimize := false;

  HotKey.VirtKey := vk_F5;
  HotKey.Modifiers := MOD_Win;
  MacroRecorder.StartRecMacrokey := HotKey;
  HotKey.VirtKey := vk_F7;
  MacroRecorder.StartPlayMacrokey := HotKey;
  HotKey.VirtKey := vk_F6;
  MacroRecorder.Breakkey := HotKey;
end;

procedure TRecorderMainForm.ShowTestWindowMenuClick(Sender: TObject);
begin
  TestForm.Show;
  Status('TestForm is visible');
end;

procedure TRecorderMainForm.QuitMenuClick(Sender: TObject);
begin
  Close;
end;

procedure TRecorderMainForm.RecordStartMenuClick(Sender: TObject);
begin
  if DoMinimize then Application.Minimize;
  MacroRecorder.StartRecord;
end;

procedure TRecorderMainForm.RecordStopMenuClick(Sender: TObject);
begin
  MacroRecorder.StopRecord;
  ShowEventListMenuClick(ShowEventListMenu);
end;

procedure TRecorderMainForm.PlayMenuClick(Sender: TObject);
begin
  if DoMinimize then Application.Minimize;
  MacroRecorder.StartPlay;
end;

procedure TRecorderMainForm.UpdateMenus;
begin
  UseOriginSpeedMenu.Checked := UseOriginalSpeed in MacroRecorder.Options;
  EnableTaskSwitchMenu.Checked := EnableTaskSwitch in MacroRecorder.Options;
  EnableModalMenu.Checked := EnableModalRecording in MacroRecorder.Options;
end;

procedure TRecorderMainForm.UseOriginSpeedMenuClick(Sender: TObject);
begin
  with UseOriginSpeedMenu do
  begin
    Checked := not(Checked);
    if Checked then MacroRecorder.Options := MacroRecorder.Options + [UseOriginalSpeed]
               else MacroRecorder.Options := MacroRecorder.Options - [UseOriginalSpeed];
  end;
end;

procedure TRecorderMainForm.EnableTaskSwitchMenuClick(Sender: TObject);
begin
  with EnableTaskSwitchMenu do
  begin
    Checked := not(Checked);
    if Checked then MacroRecorder.Options := MacroRecorder.Options + [EnableTaskSwitch]
               else MacroRecorder.Options := MacroRecorder.Options - [EnableTaskSwitch];
  end;
end;

procedure TRecorderMainForm.EnableModalMenuClick(Sender: TObject);
begin
  with EnableModalMenu do
  begin
    Checked := not(Checked);
    if Checked then MacroRecorder.Options := MacroRecorder.Options + [EnableModalRecording]
               else MacroRecorder.Options := MacroRecorder.Options - [EnableModalRecording];
  end;
end;

procedure TRecorderMainForm.MinimizeMenuClick(Sender: TObject);
begin
  with MinimizeMenu do
  begin
    Checked := not(Checked);
    DoMinimize := Checked;
  end;
end;

procedure TRecorderMainForm.ShowEventListMenuClick(Sender: TObject);
var
  I: Integer;
  NewEntry: TListItem;
begin
  with EventListView do
  begin
    Items.BeginUpdate;
    Items.Clear;
    try
      for I := 0 to MacroRecorder.EventCount - 1 do
      begin
        NewEntry := Items.Add;
        with NewEntry, MacroRecorder do
        begin
          case Events[I].Message of
            wm_MouseMove: Caption := 'WM_MouseMove';
            wm_KeyDown: Caption := 'WM_KeyDown';
            wm_KeyUp: Caption := 'WM_KeyUp';
            WM_LButtonDown: Caption := 'WM_LButtonDown';
            WM_LButtonUp: Caption := 'WM_LButtonUp';
            {For more see Messages.Pas or WinAPI-Help}
            else Caption := IntToStr(Events[I].Message);
          end;
          SubItems.Add(IntToStr(Events[I].Time - RecordStart));
          SubItems.Add(IntToStr(Times[I]));
          SubItems.Add(IntToStr(Events[I].ParamL));
          SubItems.Add(IntToStr(Events[I].ParamH));
          SubItems.Add(IntToStr(Events[I].HWnd));
        end;
      end;
    finally
      Items.EndUpdate;
    end;
  end;
end;

procedure TRecorderMainForm.MacroRecorderPlayNext;
begin
  Status(Format('%d Events played', [MacroRecorder.EventCount]));
end;

procedure TRecorderMainForm.MacroRecorderRecordNext;
begin
  Status(Format('%d Events recorded', [MacroRecorder.EventCount]));
end;

procedure TRecorderMainForm.MacroRecorderStartPlayBack;
begin
  Status('PlayBack starting');
end;

procedure TRecorderMainForm.MacroRecorderStartRecord;
begin
  Status('start Recording');
end;

procedure TRecorderMainForm.MacroRecorderStopPlayBack;
begin
  if DoMinimize then Application.Restore;
  Status('stoping PlayBack');
end;

procedure TRecorderMainForm.MacroRecorderStopRecord;
begin
  if DoMinimize then Application.Restore;
  Status(Format('Recording stopped, Recorded %d Events', [MacroRecorder.EventCount]));
  ShowEventListMenuClick(ShowEventListMenu);
end;

procedure TRecorderMainForm.MacroFileOpenMenuClick(Sender: TObject);
begin
  if OpenDialog.Execute then
  begin
    MacroRecorder.LoadFromFile(OpenDialog.FileName);
    UpdateMenus;
    ShowEventListMenuClick(ShowEventListMenu);
    Status(Format('Macro mit %d Events geladen', [MacroRecorder.EventCount]));
  end;
end;

procedure TRecorderMainForm.MacroFileSaveMenuClick(Sender: TObject);
begin
  if SaveDialog.Execute then
  begin
    MacroRecorder.SaveToFile(SaveDialog.FileName);
    Status(Format('Macro mit %d Events gespeichert', [MacroRecorder.EventCount]));
  end;
end;

procedure TRecorderMainForm.FormKeyDown(Sender: TObject; var Key: Word;
  Shift: TShiftState);
begin
  if Key = vk_NumPad1 then StartPlayback;
end;

procedure TRecorderMainForm.Kill3Sekunden1Click(Sender: TObject);
var
  I: Integer;
begin
  for I := 0 to MacroRecorder.EventCount - 1 do
    if MacroRecorder.Times[I] > 3000 then         {3000 ms = 3 seconds}
       MacroRecorder.Times[I] := 3000;
  ShowEventListMenuClick(ShowEventListMenu);
end;

end.
